package application;

import model.*;
import view.*;
import database.*;


public class TestModelWithFileData {
	public static void main(String [] args)
	{
		IUserModel model=new UserModel();
		IViewer viewer=new TextViewer();
		
		IDataDelegate dal=new FileDataDelegate("registered.txt","users.txt",",");
		
		model.setDataDelegate(dal);
		try
		{
			model.initialize();
		}catch(DataException de){
			System.out.println(de.getMessage());
			return;
		}
		
		viewer.setModel(model);
		
		//test best case scenario
		System.out.println("--------------------------");
		System.out.println("Test 1. Testing valid user login");
		System.out.println("--------------------------");
		if(model.authorizeUser("Bob", "p1") )
		{
			viewer.displayUser();
		}
		else
		{
			viewer.displayError("Invalid user name or password");
		}
		System.out.println();
		
		//test invalid user name
		System.out.println("--------------------------");
		System.out.println("Test 2. Testing invalid user name");
		System.out.println("--------------------------");
		if(model.authorizeUser("Bobby", "p1") )
		{
			viewer.displayUser();
		}
		else
		{
			viewer.displayError("Invalid user name or password");
		}
		System.out.println();
		
		//test invalid password
		System.out.println("--------------------------");
		System.out.println("Test 3. Testing invalid password");
		System.out.println("--------------------------");
		if(model.authorizeUser("Bob", "p2") )
		{
			viewer.displayUser();
		}
		else
		{
			viewer.displayError("Invalid user name or password");
		}
		System.out.println();
		System.out.println();
		
		//test saving modified data 
		System.out.println("--------------------------");
		System.out.println("Test 4. Testing saving modified user score and name");
		System.out.println("--------------------------");
		
		model.authorizeUser("Margaret", "p2");
		
		System.out.println("User before score change:");
		viewer.displayUser();
		System.out.println();
			
		User user=model.getCurrent();
		user.setScore(2);
		model.updateCurrent(user.getName(), user);
		try
		{
			model.saveAllChanges();
			model.initialize();
		}
		catch( DataException de){
			System.out.println(de.getMessage());
			return;
		}
		
		model.authorizeUser("Margaret", "p2");
		System.out.println("User after score change:");
		viewer.displayUser();
		System.out.println();
		
		user=model.getCurrent();
		String oldName=user.getName();
		user.setName("Marge");
		model.updateCurrent(oldName, user);
		
		try
		{
			model.saveAllChanges();
			model.initialize();
		}
		catch( DataException de){
			System.out.println(de.getMessage());
			return;
		}
		
		model.authorizeUser("Marge", "p2");
		System.out.println("User after name change:");
		viewer.displayUser();
		System.out.println();
		
	}
}
