package database;

import java.util.*;
import java.io.*;
import model.*;

public class FileDataDelegate implements IDataDelegate{

	String registeredUsersFileName;
	String usersWithScoresFileName;
	String dataDelimiter;
	
	public FileDataDelegate(String registeredUsersFileName,String usersWithScoresFileName, String fileDelimiter )
	{
		this.registeredUsersFileName=registeredUsersFileName;
		this.usersWithScoresFileName=usersWithScoresFileName;
		this.dataDelimiter=fileDelimiter;
	}
	
	public java.util.Map<String,User> load() throws DataException
	{
		Map <String,User> usersWithScores=new HashMap<String, User>();
		
		try
		{
			BufferedReader br=new BufferedReader(new FileReader(usersWithScoresFileName));
			String line=null;
			while((line=br.readLine())!=null)
			{
				String [] lineData=line.split(dataDelimiter);
				String name=lineData[0];
				String strScore=lineData[1];
				try
				{
					int score=Integer.parseInt(strScore);
					User user=new User(name);
					user.setScore(score);
					usersWithScores.put(name, user);
				}catch(NumberFormatException nfe){
					br.close();
					throw new DataException("Invalid data format.");
				}				
			}
			br.close();
		}
		catch(IOException ioe){
			throw new DataException(ioe.getMessage());
		}		
		
		return usersWithScores;
	}
	
	public boolean save( java.util.Map<String,User> users) throws DataException
	{
		//storing usersWithScores into persistent data store
		try
		{
			BufferedWriter bw=new BufferedWriter(new FileWriter(usersWithScoresFileName));
			for(User user: users.values())
			{
				bw.write(user.getName()+dataDelimiter+user.getScore()+System.getProperty("line.separator"));
			}
			bw.close();
		}catch(IOException ioe)
		{
			throw new DataException(ioe.getMessage());
		}
		return true;
	}
	
	public boolean login(String name, String password) throws DataException
	{
		try
		{
			BufferedReader br=new BufferedReader(new FileReader(registeredUsersFileName));
			String line=null;
			while((line=br.readLine())!=null)
			{
				String [] lineData=line.split(dataDelimiter);
				String dbname=lineData[0];
				if(dbname.equals(name))
				{
					String dbpassword=lineData[1];
					if(dbpassword.equals(password))
					{
						br.close();
						return true;
					}
				}		
			}
			br.close();
		}
		catch(IOException ioe){
			throw new DataException("Error reading file "+registeredUsersFileName);
		}		
		
		return false;
	}

}
